==> XCorVar-0.1.0.tar.gz: XCorVar-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import os
import io
import sys

from shutil import rmtree
from setuptools import find_packages, setup, Command

# Package meta-data .
NAME = 'XCorVar'
DESCRIPTION = 'Quantitative Analysis Library.'
URL = 'https://github.com/matt-charr/'
EMAIL = 'matthieu.charrier.pro@gmail.com'
AUTHOR = 'Matthieu Charrier'
REQUIRES_PYTHON = '>=3.9.0'
VERSION = '0.1.0'

# What packages are required for this module to be executed ?
REQUIRED = []

# What packages are optional ?
EXTRAS = {}

# Get the absolute path of this file
here = os.path.abspath (os.path.dirname (__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file !

try:
    with io.open (os.path.join (here, 'README.md'), encoding='utf-8') as file:
        long_description = '\n' + file.read ()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower ().replace ("-", "_").replace (" ", '_') 
    with open (os.path.join (here, project_slug, '__version__.py')) as file:
        exec (file.read (), about)
else:
    about ['__version__'] = VERSION

class uploadCommand (Command):
    '''
    Support setup.py upload
    '''

    description = 'Build and publish the package'
    user_options = []

    @staticmethod
    def status (s):
        '''
        prints things in bold
        '''
        print ('\033[1m{0}\033[0m'.format (s))

    def initialize_options (self):
        pass

    def finalize_options (self):
        pass

    def run (self):
        try:
            self.status ('Removing previous build ...')
            rmtree (os.path.join (here, 'dist'))
        except OSError:
            pass
        self.status ('Building Source and Wheel (universal) distribution ...')
        os.system ('{0} setup.py sdist bdist_wheel --universal'.format (sys.executable))
        self.status ('Uploading the package to PyPI via Twine ...')
        os.system ('twine upload dist/*')
        self.status ('Pushing git tags ...')
        os.system ('git tag v{0}'.format (about ['__version__']))
        os.system ('git push --tags')
        sys.exit()

# Where the magic happens:
setup (
    name=NAME,
    version=about ['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages (exclude=["tests", "*.tests", "*.tests.*"]),
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license='MIT',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    cmdclass={
        'upload': uploadCommand,
    },
)

==> XCorVar-0.1.2.tar.gz: XCorVar-0.1.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import io
import sys

from shutil import rmtree
from setuptools import find_packages, setup, Command

NAME = 'XCorVar'
DESCRIPTION = 'Quantitative Analysis Library'
URL = 'https://github.com/matt-charr/' + NAME
EMAIL = 'matthieu.charrier.pro@gmail.com'
AUTHOR = 'Matthieu Charrier'
REQUIRES_PYTHON = '>=3.9.0'
VERSION = '0.1.2'
REQUIRED = ['scipy']
EXTRAS = {}

here = os.path.abspath (os.path.dirname (__file__))

try:
    with io.open (os.path.join (here, 'README.md'), encoding='utf-8') as file:
        long_description = '\n' + file.read ()
except FileNotFoundError:
    long_description = DESCRIPTION

about = {}
if not VERSION:
    project_slug = NAME.lower ().replace ("-", "_").replace (" ", '_') 
    with open (os.path.join (here, project_slug, '__version__.py')) as file:
        exec (file.read (), about)
else:
    about ['__version__'] = VERSION

class uploadCommand (Command):

    description = 'Build and publish the package'
    user_options = []

    @staticmethod
    def status (s):
        print ('\033[1m{0}\033[0m'.format (s))

    def initialize_options (self):
        pass

    def finalize_options (self):
        pass

    def run (self):
        try:
            self.status ('Removing previous build ...')
            rmtree (os.path.join (here, 'dist'))
        except OSError:
            pass
        self.status ('Building Source and Wheel (universal) distribution ...')
        os.system ('{0} setup.py sdist bdist_wheel --universal'.format (sys.executable))
        self.status ('Uploading the package to PyPI via Twine ...')
        os.system ('twine upload dist/*')
        self.status ('Pushing git tags ...')
        os.system ('git tag v{0}'.format (about ['__version__']))
        os.system ('git push --tags')
        sys.exit()

setup (
    name=NAME,
    version=about ['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages (exclude=["tests", "*.tests", "*.tests.*"]),
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    cmdclass={
        'upload': uploadCommand,
    },
)
